@@ -3,8 +3,8 @@ local files      = require 'files'
 local vm         = require 'vm'
 local findSource = require 'core.find-source'
 local guide      = require 'parser.guide'
-local infer      = require 'vm.infer'
 local rpath      = require 'workspace.require-path'
+local jumpSource = require 'core.jump-source'
 
 local function sortResults(results)
     -- 先按照顺序排序
@@ -52,8 +52,9 @@ local accept = {
     ['doc.class.name']   = true,
     ['doc.extends.name'] = true,
     ['doc.alias.name']   = true,
-    ['doc.see.name']     = true,
-    ['doc.see.field']    = true,
+    ['doc.cast.name']    = true,
+    ['doc.enum.name']    = true,
+    ['doc.field.name']   = true,
 }
 
 local function checkRequire(source, offset)
@@ -75,7 +76,7 @@ local function checkRequire(source, offset)
         return nil
     end
     if     libName == 'require' then
-        return rpath.findUrisByRequirePath(guide.getUri(source), literal)
+        return rpath.findUrisByRequireName(guide.getUri(source), literal)
     elseif libName == 'dofile'
     or     libName == 'loadfile' then
         return workspace.findUrisByFilePath(literal)
@@ -134,20 +135,26 @@ return function (uri, offset)
     local defs = vm.getDefs(source)
 
     for _, src in ipairs(defs) do
-        if src.dummy then
-            goto CONTINUE
-        end
         local root = guide.getRoot(src)
         if not root then
             goto CONTINUE
         end
         src = src.field or src.method or src.index or src
+        if src.type == 'doc.class' then
+            src = src.class
+        end
+        if src.type == 'doc.alias' then
+            src = src.alias
+        end
+        if src.type == 'doc.enum' then
+            src = src.enum
+        end
         if src.type == 'doc.class.name'
         or src.type == 'doc.alias.name'
         or src.type == 'doc.type.function'
         or src.type == 'doc.type.array'
         or src.type == 'doc.type.table'
-        or src.type == 'doc.type.ltable' then
+        or src.type == 'function' then
             results[#results+1] = {
                 target = src,
                 uri    = root.uri,
@@ -162,6 +169,7 @@ return function (uri, offset)
     end
 
     sortResults(results)
+    jumpSource(results)
 
     return results
 end
