@@ -550,11 +550,14 @@ local function matchCall(source)
     or call.node ~= source then
         return
     end
-    local funcs = vm.getMatchedFunctions(source, call.args)
     local myNode = vm.getNode(source)
     if not myNode then
         return
     end
+    local funcs = vm.getExactMatchedFunctions(source, call.args)
+    if not funcs then
+        return
+    end
     local needRemove
     for n in myNode:eachObject() do
         if n.type == 'function'
@@ -870,7 +873,7 @@ local function compileCallArgNode(arg, call, callNode, fixIndex, myIndex)
     ---@type integer?, table<any, boolean>?
     local eventIndex, eventMap
     if call.args then
-        for i = 1, 2 do
+        for i = 1, 10 do
             local eventArg = call.args[i + fixIndex]
             if not eventArg then
                 break
